California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 022 - PROHIBITS THE STATE FROM TAKING FUNDS USED FOR TRANSPORTATION OR LOCAL GOVERNMENT PROJECTS AND SERVICES. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322292 | YES ON 22 / PROTECT LOCAL SERVICES, A COALITION OF PUBLIC SAFETY, LOCAL GOVERNMENT, TRANSPORTATION, AND TAXPAYERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1328134 | NO ON 22 - CITIZENS AGAINST TAXPAYER GIVEAWAYS, SPONSORED BY CALIFONRIA PROFESSIONAL FIREFIGHTERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1254399 | LEAGUE OF CALIFORNIA CITIES CITIPAC, SUPPORTING PROPOSITION 22 | SUPPORT